function ssw_imapcoord2html, mapfile, imapcoord, urls, mapname=mapname
;
;+
;   Name: ssw_imapcoord2html 
;
;   Puropose: return html for imagemap generation/reference 
;
;   Input Parameters:
;      mapfile - graphic file (gif/png/jpeg) of map relative or full URL 
;      imapcoord - strarry containing comma delimited lists of coord
;                  (for example, output of get_imagemap_coord,/string and
;                   evt_grid,/imap,IMAGEMAP_COORD=imapcoord , etc)
;      urls - urls mapping to imapcoord (1:1 vector) relative path names
;                  or fully qualified URLs
;   Keyword Parameters:
;      mapname - optional map reference name used in html
;                (default is derived from MAPFILE with extension removed)
;
;   Output:
;      function returns html  for document insertion as follows
;         (items in brackets are inputs to this routine)
;
;      First element (0) is a reference line like:
;          <img border="0" src="[mapfile]" usemap="#[mapname]">
;      Second element (1) is map defiinition initiation line like:
;          <map name="[mapname]">
;      Elements(2:n) are mapfile:imapcoord:urls mapping lines like:
;          <area shape="rect" coords="[imapcoord[i]]" href="[urls[i]]">
;      Penultimate element and last elements are standard imap close..
;          <area shape="default" nohref>
;          </map>
; 
;    Note: region shape is currently either 'rect' or 'circle'
;          IMAPCORD input in form of "a,b,c,d" (4 elements) imlies RECT
;                                    "a,b,c"   (3 elements) implies CIRCLE
;
;   History:
;      28-Feb-2002 - S.L.Freeland - a piece of the utplot,plot_map..->www puzzle 
;
;- 
;       
if n_params() lt 3 then begin 
   box_message,['Need 3 input parameters...',$ 
     'IDL> imaphtml=ssw_imapcoord2httml(mapfile,imapcoord,urls [,mapname=xx])']
   return,''
endif
if n_elements(imapcoord) ne n_elements(urls) then begin 
   box_message,'Number of coordinate sets (imapcoord) must = #urls"
   return,''
endif
 
case 1 of
   strpos(mapfile,'http:') ne -1: break_url,mapfile,servers,paths,files
   else: begin 
      break_file,mapfile,ll,paths,ff,vv,ee
      files=ff+vv+ee
   endcase
endcase
if not data_chk(mapname,/string) then mapname=strsplit(files,'.',/head)
mapname=mapname(0)

minit='<img border="0" src="'+mapfile(0)+'"" usemap="#'+mapname+'">'
mname='<map name="'+mapname+'">'

; do the coord:url mapping (mix of circles and rectangles ok?)
cbmap=fix(byte(imapcoord) eq 44)     ; boolean, where commas 
ctot=total(cbmap,1)-2                 ; normalized comma total for each element

if min(ctot) lt 0 or max(ctot) gt 1 then begin 
   box_message,'Incorrect coord format,Need "1,2,3,4" (rect) or "1,2,3" (circle)'
   return,''
endif

shape=(['circle','rect'])(ctot) 
shapecmds='<area shape="'+shape+'" coords ="'+ imapcoord + $
                               ' href="' + urls+ '">'

mclose=['<area shape="default" nohref>','</map>']

retval=[minit,mname,shapecmds,mclose]
return,retval
end
